#Turntable API

A simple nodejs wrapper for the turntable API

## Installation
    npm install ttapi

## Examples

### Chat bot

This bot respond to anybody who write "/hello" on the chat.

    var Bot = require('ttapi');
    var bot = new Bot(AUTH, USERID, ROOMID);

    bot.on('speak', function (data) {
       // Respond to "/hello" command
       if (data.text.match(/^\/hello$/)) {
          bot.speak('Hey! How are you '+data.name+' ?');
       }
    });


### Http Server

This bot create an http server and give his version number when we ask for "http://127.0.0.1:8080/version/" this page.

    var Bot = require('ttapi');
    var bot = new Bot(AUTH, USERID, ROOMID);
    bot.listen(8080, '127.0.0.1');
    
    var myScriptVersion = '0.0.0';
    
    bot.on('httpRequest', function (req, res) {
       var method = req.method;
       var url    = req.url;
       switch (url) {
          case '/version/':
             if (method == 'GET') {
                res.writeHead(200, { 'Content-Type': 'application/json' });
                return res.end('{"version":"'+myScriptVersion+'"}');
             } else {
                res.writeHead(500);
                return res.end();
             }
             break;
       }
       res.writeHead(500);
       return res.end();
    });

You can easily test it like this:

    curl http://127.0.0.1:8080/version/


### Simple

    var Bot    = require('ttapi');
    var AUTH   = 'auth+live+xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
    var USERID = 'xxxxxxxxxxxxxxxxxxxxxxxx';
    var ROOMID = 'xxxxxxxxxxxxxxxxxxxxxxxx';

    var bot = new Bot(AUTH, USERID);

    bot.on('ready',        function (data) { bot.roomRegister(ROOMID); });
    bot.on('roomChanged',  function (data) { console.log('The bot has changed room.', data); });

    bot.on('speak',        function (data) { console.log('Someone has spoken', data); });
    bot.on('update_votes', function (data) { console.log('Someone has voted',  data); });
    bot.on('registered',   function (data) { console.log('Someone registered', data); });

# Documentation


## Events

[Here are some examples of the data that you'll receive from those events.](https://github.com/alaingilbert/Turntable-API/tree/master/turntable_data)

### on('httpRequest', function (request, response) { })

Triggered when the bot receive an http request.

### on('registered', function (data) { })

Triggered when a user register in the room.

### on('deregistered', function (data) { })

Triggered when a user leave the room.

### on('speak', function (data) { })

Triggered when a new message is send via the chat.

### on('newsong', function (data) { })

Triggered when a new song start.

### on('nosong', function (data) { })

Triggered when there is no song.

### on('update_votes', function (data) { })

Triggered when a user vote.

### on('booted_user', function (data) { })

Triggered when a user is booted.

### on('update_user', function (data) { })

Triggered when a user change his name/infos.

### on('add_dj', function (data) { })

Triggered when a user take a dj spot.

### on('rem_dj', function (data) { })

Triggered when a user leave a dj spot.

### on('new_moderator', function (data) { })

Triggered when a user is granted to moderator title.

### on('rem_moderator', function (data) { })

Triggered when a user loose his moderator title.


## Actions

### listen ( port, address )

Start an http server.

### roomNow ( [callback:fn] )

Get the turntable server time.

### listRooms ( skip=0:int [, callback:fn] )

Get 20 rooms.

### roomRegister ( roomId:string [, callback:fn] )

Register in a room.

### roomDeregister ( [callback:fn] )

Deregister from the current room.

### roomInfo ( [callback:fn] )

Get the current room informations.

### speak ( msg:string [, callback:fn] )

Broadcast a message on the chat.

### bootUser ( userId:string, reason:string [, callback:fn] )

Boot a user.

### addModerator ( userId:string [, callback:fn] )

Add a moderator.

### remModerator ( userId:string [, callback:fn] )

Remove a moderator.

### addDj ( [callback:fn] )

Add yourself as a Dj.

### remDj ( [[userId:string, ]callback:fn] )

Remove a Dj.

### stopSong ( [callback:fn] )

Skip the current song.

### vote ( val:enum('up', 'down') [, callback:fn] )

Vote for the current song.

### userAuthenticate ( [callback:fn] )

Authenticate the user.

### userInfo ( [callback:fn] )

Get the current user informations.

### modifyLaptop ( laptop:enum('linux', 'mac', 'pc', 'chrome') [, callback:fn] )

Modify your laptop.

### modifyName ( name:string [, callback:fn] )

Modify your name.

### setAvatar ( avatarId:int [, callback:fn] )

Set your avatar.

### playlistAll ( playlistName:string [, callback:fn] )

Get all informations about a playlist.

### playlistAdd ( playlistName:string, songId:string [, callback:fn] )

Add a song on a playlist.

### playlistRemove ( playlistName:string, index:int [, callback:fn] )

Remove a song on a playlist.
